@@ -12,7 +12,7 @@ use Date::Calc            qw/Delta_Days/;
 use Carp                  qw/croak/;
 use Encode                qw/encode_utf8/;
 
-my $VERSION = '0.3';
+my $VERSION = '0.4';
 
 #======================================================================
 # GLOBALS
@@ -238,7 +238,7 @@ sub worksheet_rels {
 #======================================================================
 
 sub save_as {
-  my ($self, $file_name) = @_;
+  my ($self, $target) = @_;
 
   # assemble all parts within the zip, except sheets and tables that were already added previously
   my $zip = $self->{zip};
@@ -252,9 +252,9 @@ sub save_as {
   $zip->addString($self->styles,             "xl/styles.xml");
 
   # write the Zip archive
-  my $write_result = $zip->writeToFileNamed($file_name);
+  my $write_result = ref $target ? $zip->writeToFileHandle($target) : $zip->writeToFileNamed($target);
   $write_result == AZ_OK
-    or croak "could not write into $self->{xlsx}";
+    or croak "could not save Zip archive into " . (ref($target) || $target);
 }
 
 
@@ -588,9 +588,10 @@ only once within the workbook).
 
 =head2 save_as
 
-  $writer->save_as($filename);
+  $writer->save_as($target);
 
-Writes the workbook contents into the specified C<$filename>.
+Writes the workbook contents into the specified C<$target>, which can be either
+a filename or filehandle opened for writing.
 
 
 =head1 ARCHITECTURAL NOTE
